@@ -1,4 +1,4 @@
-#' Control Function for Descriptive Statistics
+#' Control function for descriptive statistics
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
@@ -6,20 +6,16 @@
 #' details for [s_summary()]. This function family is mainly used by [analyze_vars()].
 #'
 #' @inheritParams argument_convention
-#' @param quantiles (`numeric`)\cr of length two to specify the quantiles to calculate.
-#' @param quantile_type (`numeric`)\cr between 1 and 9 selecting quantile algorithms to be used.
+#' @param quantiles (`numeric(2)`)\cr vector of length two to specify the quantiles to calculate.
+#' @param quantile_type (`numeric(1)`)\cr number between 1 and 9 selecting quantile algorithms to be used.
 #'   Default is set to 2 as this matches the default quantile algorithm in SAS `proc univariate` set by `QNTLDEF=5`.
 #'   This differs from R's default. See more about `type` in [stats::quantile()].
-#' @param test_mean (`numeric`)\cr to test against the mean under the null hypothesis when calculating p-value.
-#'
-#' @note Deprecation cycle started for `control_summarize_vars` as it is going to renamed into
-#'   `control_analyze_vars`. Intention is to reflect better the core underlying `rtables`
-#'   functions; in this case [analyze_vars()] wraps [rtables::analyze()].
+#' @param test_mean (`numeric(1)`)\cr number to test against the mean under the null hypothesis when calculating
+#'   p-value.
 #'
 #' @return A list of components with the same names as the arguments.
 #'
-#' @export control_analyze_vars control_summarize_vars
-#' @aliases control_summarize_vars
+#' @export
 control_analyze_vars <- function(conf_level = 0.95,
                                  quantiles = c(0.25, 0.75),
                                  quantile_type = 2,
@@ -32,10 +28,7 @@ control_analyze_vars <- function(conf_level = 0.95,
   list(conf_level = conf_level, quantiles = quantiles, quantile_type = quantile_type, test_mean = test_mean)
 }
 
-control_summarize_vars <- control_analyze_vars
-
-
-#' Analyze Variables
+#' Analyze variables
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
@@ -51,10 +44,6 @@ control_summarize_vars <- control_analyze_vars
 #' This utilizes the [format_auto()] formatting function. Note that only data for the current row & variable (for all
 #' columns) will be considered (`.df_row[[.var]]`, see [`rtables::additional_fun_params`]) and not the whole dataset.
 #'
-#' @note
-#' * Deprecation cycle started for `summarize_vars` which has been renamed to `analyze_vars`. This renaming is intended
-#'   to better reflect its core underlying `rtables` functions - in this case [rtables::analyze()].
-#'
 #' @inheritParams argument_convention
 #' @param .stats (`character`)\cr statistics to select for the table. Run `get_stats("analyze_vars_numeric")` to see
 #'   statistics available for numeric variables, and `get_stats("analyze_vars_counts")` for statistics available
@@ -86,10 +75,10 @@ s_summary <- function(x,
 #' @param control (`list`)\cr parameters for descriptive statistics details, specified by using
 #'   the helper function [control_analyze_vars()]. Some possible parameter options are:
 #'   * `conf_level` (`proportion`)\cr confidence level of the interval for mean and median.
-#'   * `quantiles` (`numeric`)\cr vector of length two to specify the quantiles.
-#'   * `quantile_type` (`numeric`)\cr between 1 and 9 selecting quantile algorithms to be used.
+#'   * `quantiles` (`numeric(2)`)\cr vector of length two to specify the quantiles.
+#'   * `quantile_type` (`numeric(1)`)\cr between 1 and 9 selecting quantile algorithms to be used.
 #'     See more about `type` in [stats::quantile()].
-#'   * `test_mean` (`numeric`)\cr value to test against the mean under the null hypothesis when calculating p-value.
+#'   * `test_mean` (`numeric(1)`)\cr value to test against the mean under the null hypothesis when calculating p-value.
 #'
 #' @return
 #'   * If `x` is of class `numeric`, returns a `list` with the following named `numeric` items:
@@ -141,7 +130,6 @@ s_summary <- function(x,
 #' s_summary(x, stats = NULL)
 #'
 #' ## Benefits in `rtables` contructions:
-#' require(rtables)
 #' dta_test <- data.frame(
 #'   Group = rep(LETTERS[1:3], each = 2),
 #'   sub_group = rep(letters[1:2], each = 3),
@@ -331,7 +319,7 @@ s_summary.factor <- function(x,
 #' @describeIn analyze_variables Method for `character` class. This makes an automatic
 #'   conversion to factor (with a warning) and then forwards to the method for factors.
 #'
-#' @param verbose (`logical`)\cr Defaults to `TRUE`, which prints out warnings and messages. It is mainly used
+#' @param verbose (`flag`)\cr defaults to `TRUE`, which prints out warnings and messages. It is mainly used
 #'   to print out information about factor casting.
 #'
 #' @note
@@ -435,7 +423,7 @@ s_summary.logical <- function(x,
 #' @describeIn analyze_variables Formatted analysis function which is used as `afun` in `analyze_vars()` and
 #'   `compare_vars()` and as `cfun` in `summarize_colvars()`.
 #'
-#' @param compare (`logical`)\cr Whether comparison statistics should be analyzed instead of summary statistics
+#' @param compare (`flag`)\cr whether comparison statistics should be analyzed instead of summary statistics
 #'   (`compare = TRUE` adds `pval` statistic comparing against reference group).
 #'
 #' @return
@@ -481,15 +469,9 @@ a_summary <- function(x,
                       .labels = NULL,
                       .indent_mods = NULL,
                       na.rm = TRUE, # nolint
-                      na_level = lifecycle::deprecated(),
                       na_str = default_na_str(),
                       ...) {
   extra_args <- list(...)
-  if (lifecycle::is_present(na_level)) {
-    lifecycle::deprecate_warn("0.9.1", "a_summary(na_level)", "a_summary(na_str)")
-    na_str <- na_level
-  }
-
   if (is.numeric(x)) {
     type <- "numeric"
     if (!is.null(.stats) && any(grepl("^pval", .stats))) {
@@ -552,52 +534,11 @@ a_summary <- function(x,
   )
 }
 
-#' Constructor Function for [analyze_vars()] and [summarize_colvars()]
-#'
-#' @description `r lifecycle::badge("deprecated")`
-#'
-#' Constructor function which creates a combined formatted analysis function.
-#'
-#' @inheritParams argument_convention
-#' @param .indent_mods (named `vector` of `integer`)\cr indent modifiers for the labels. Each element of the vector
-#'   should be a name-value pair with name corresponding to a statistic specified in `.stats` and value the indentation
-#'   for that statistic's row label.
-#'
-#' @return Combined formatted analysis function for use in [analyze_vars()].
-#'
-#' @note This function has been deprecated in favor of direct implementation of `a_summary()`.
-#'
-#' @seealso [analyze_vars()]
-#'
-#' @export
-create_afun_summary <- function(.stats, .formats, .labels, .indent_mods) {
-  lifecycle::deprecate_warn(
-    "0.8.5.9010",
-    "create_afun_summary()",
-    details = "Please use a_summary() directly instead."
-  )
-  function(x,
-           .ref_group,
-           .in_ref_col,
-           ...,
-           .var) {
-    a_summary(x,
-      .stats = .stats,
-      .formats = .formats,
-      .labels = .labels,
-      .indent_mods = .indent_mods,
-      .ref_group = .ref_group,
-      .in_ref_col = .in_ref_col,
-      .var = .var, ...
-    )
-  }
-}
-
 #' @describeIn analyze_variables Layout-creating function which can take statistics function arguments
 #'   and additional format arguments. This function is a wrapper for [rtables::analyze()].
 #'
 #' @param ... arguments passed to `s_summary()`.
-#' @param .indent_mods (named `vector` of `integer`)\cr indent modifiers for the labels. Each element of the vector
+#' @param .indent_mods (named `integer`)\cr indent modifiers for the labels. Each element of the vector
 #'   should be a name-value pair with name corresponding to a statistic specified in `.stats` and value the indentation
 #'   for that statistic's row label.
 #'
@@ -665,12 +606,11 @@ create_afun_summary <- function(.stats, .formats, .labels, .indent_mods) {
 #'   ) %>%
 #'   build_table(dt)
 #'
-#' @export analyze_vars summarize_vars
+#' @export
 #' @order 2
 analyze_vars <- function(lyt,
                          vars,
                          var_labels = vars,
-                         na_level = lifecycle::deprecated(),
                          na_str = default_na_str(),
                          nested = TRUE,
                          ...,
@@ -682,11 +622,6 @@ analyze_vars <- function(lyt,
                          .formats = NULL,
                          .labels = NULL,
                          .indent_mods = NULL) {
-  if (lifecycle::is_present(na_level)) {
-    lifecycle::deprecate_warn("0.9.1", "analyze_vars(na_level)", "analyze_vars(na_str)")
-    na_str <- na_level
-  }
-
   extra_args <- list(.stats = .stats, na.rm = na.rm, na_str = na_str, ...)
   if (!is.null(.formats)) extra_args[[".formats"]] <- .formats
   if (!is.null(.labels)) extra_args[[".labels"]] <- .labels
@@ -706,8 +641,3 @@ analyze_vars <- function(lyt,
     section_div = section_div
   )
 }
-#' @describeIn analyze_variables `r lifecycle::badge("deprecated")` Use `analyze_vars` instead.
-summarize_vars <- function(...) {
-  lifecycle::deprecate_warn(when = "0.8.5.9010", "summarize_vars()", "analyze_vars()")
-  analyze_vars(...)
-}
