@@ -1,4 +1,4 @@
-#' Compare Variables Between Groups
+#' Compare variables between groups
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
@@ -24,9 +24,8 @@
 #' * For `compare_vars()`, the column split must define a reference group via `ref_group` so that the comparison
 #'   is well defined.
 #'
-#' @seealso Relevant constructor function [create_afun_compare()], [s_summary()] which is used internally
-#'   to compute a summary within `s_compare()`, and [a_compare()] which is used (with `compare = TRUE`) as the analysis
-#'   function for `compare_vars()`.
+#' @seealso [s_summary()] which is used internally to compute a summary within `s_compare()`, and [a_summary()]
+#'   which is used (with `compare = TRUE`) as the analysis function for `compare_vars()`.
 #'
 #' @name compare_variables
 #' @include analyze_variables.R
@@ -149,7 +148,7 @@ s_compare.factor <- function(x,
 #' @describeIn compare_variables Method for `character` class. This makes an automatic
 #'   conversion to `factor` (with a warning) and then forwards to the method for factors.
 #'
-#' @param verbose (`logical`)\cr Whether warnings and messages should be printed. Mainly used
+#' @param verbose (`flag`)\cr whether warnings and messages should be printed. Mainly used
 #'   to print out information about factor casting. Defaults to `TRUE`.
 #'
 #' @method s_compare character
@@ -250,96 +249,11 @@ s_compare.logical <- function(x,
   y
 }
 
-#' @describeIn compare_variables Formatted analysis function which is used as `afun`
-#'   in `compare_vars()`.
-#'
-#' @return
-#' * `a_compare()` returns the corresponding list with formatted [rtables::CellValue()].
-#'
-#' @note `a_compare()` has been deprecated in favor of `a_summary()` with argument `compare` set to `TRUE`.
-#'
-#' @examples
-#' # `a_compare` deprecated - use `a_summary()` instead
-#' a_compare(rnorm(10, 5, 1), .ref_group = rnorm(20, -5, 1), .stats = c("n", "pval"))
-#'
-#' @export
-a_compare <- function(x,
-                      .N_col, # nolint
-                      .N_row, # nolint
-                      .var = NULL,
-                      .df_row = NULL,
-                      .ref_group = NULL,
-                      .in_ref_col = FALSE,
-                      ...) {
-  lifecycle::deprecate_warn(
-    "0.8.3",
-    "a_compare()",
-    details = "Please use a_summary() with argument `compare` set to TRUE instead."
-  )
-  a_summary(
-    x = x,
-    .N_col = .N_col,
-    .N_row = .N_row,
-    .var = .var,
-    .df_row = .df_row,
-    .ref_group = .ref_group,
-    .in_ref_col = .in_ref_col,
-    compare = TRUE,
-    ...
-  )
-}
-
-#' Constructor Function for [compare_vars()]
-#'
-#' @description `r lifecycle::badge("deprecated")`
-#'
-#' Constructor function which creates a combined formatted analysis function.
-#'
-#' @inheritParams argument_convention
-#' @param .indent_mods (named `vector` of `integer`)\cr indent modifiers for the labels. Each element of the vector
-#'   should be a name-value pair with name corresponding to a statistic specified in `.stats` and value the indentation
-#'   for that statistic's row label.
-#'
-#' @return Combined formatted analysis function for use in [compare_vars()].
-#'
-#' @note This function has been deprecated in favor of direct implementation of `a_summary()` with argument `compare`
-#'   set to `TRUE`.
-#'
-#' @seealso [compare_vars()]
-#'
-#' @export
-create_afun_compare <- function(.stats = NULL,
-                                .formats = NULL,
-                                .labels = NULL,
-                                .indent_mods = NULL) {
-  lifecycle::deprecate_warn(
-    "0.8.5.9010",
-    "create_afun_compare()",
-    details = "Please use a_summary(compare = TRUE) directly instead."
-  )
-  function(x,
-           .ref_group,
-           .in_ref_col,
-           ...,
-           .var) {
-    a_summary(x,
-      compare = TRUE,
-      .stats = .stats,
-      .formats = .formats,
-      .labels = .labels,
-      .indent_mods = .indent_mods,
-      .ref_group = .ref_group,
-      .in_ref_col = .in_ref_col,
-      .var = .var, ...
-    )
-  }
-}
-
 #' @describeIn compare_variables Layout-creating function which can take statistics function arguments
 #'   and additional format arguments. This function is a wrapper for [rtables::analyze()].
 #'
 #' @param ... arguments passed to `s_compare()`.
-#' @param .indent_mods (named `vector` of `integer`)\cr indent modifiers for the labels. Each element of the vector
+#' @param .indent_mods (named `integer`)\cr indent modifiers for the labels. Each element of the vector
 #'   should be a name-value pair with name corresponding to a statistic specified in `.stats` and value the indentation
 #'   for that statistic's row label.
 #'
@@ -373,7 +287,6 @@ create_afun_compare <- function(.stats = NULL,
 compare_vars <- function(lyt,
                          vars,
                          var_labels = vars,
-                         na_level = lifecycle::deprecated(),
                          na_str = default_na_str(),
                          nested = TRUE,
                          ...,
@@ -385,12 +298,8 @@ compare_vars <- function(lyt,
                          .formats = NULL,
                          .labels = NULL,
                          .indent_mods = NULL) {
-  if (lifecycle::is_present(na_level)) {
-    lifecycle::deprecate_warn("0.9.1", "compare_vars(na_level)", "compare_vars(na_str)")
-    na_str <- na_level
-  }
-
   extra_args <- list(.stats = .stats, na.rm = na.rm, na_str = na_str, compare = TRUE, ...)
+
   if (!is.null(.formats)) extra_args[[".formats"]] <- .formats
   if (!is.null(.labels)) extra_args[[".labels"]] <- .labels
   if (!is.null(.indent_mods)) extra_args[[".indent_mods"]] <- .indent_mods
