@@ -1,11 +1,11 @@
-#' Re-implemented [range()] Default S3 method for numerical objects
+#' Re-implemented `range()` default S3 method for numerical objects
 #'
 #' This function returns `c(NA, NA)` instead of `c(-Inf, Inf)` for zero-length data
 #' without any warnings.
 #'
 #' @param x (`numeric`)\cr a sequence of numbers for which the range is computed.
-#' @param na.rm (`logical`)\cr indicating if `NA` should be omitted.
-#' @param finite (`logical`)\cr indicating if non-finite elements should be removed.
+#' @param na.rm (`flag`)\cr flag indicating if `NA` should be omitted.
+#' @param finite (`flag`)\cr flag indicating if non-finite elements should be removed.
 #'
 #' @return A 2-element vector of class `numeric`.
 #'
@@ -48,7 +48,7 @@ f_conf_level <- function(conf_level) {
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
-#' @param test_mean (`number`)\cr mean value to test under the null hypothesis.
+#' @param test_mean (`numeric(1)`)\cr mean value to test under the null hypothesis.
 #'
 #' @return A `string`.
 #'
@@ -58,7 +58,7 @@ f_pval <- function(test_mean) {
   paste0("p-value (H0: mean = ", test_mean, ")")
 }
 
-#' Utility function to return a named list of covariate names.
+#' Utility function to return a named list of covariate names
 #'
 #' @param covariates (`character`)\cr a vector that can contain single variable names (such as
 #'   `"X1"`), and/or interaction terms indicated by `"X1 * X2"`.
@@ -72,14 +72,14 @@ get_covariates <- function(covariates) {
   stats::setNames(as.list(cov_vars), cov_vars)
 }
 
-#' Replicate Entries of a Vector if Required
+#' Replicate entries of a vector if required
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
 #' Replicate entries of a vector if required.
 #'
 #' @inheritParams argument_convention
-#' @param n (`count`)\cr how many entries we need.
+#' @param n (`integer(1)`)\cr number of entries that are needed.
 #'
 #' @return `x` if it has the required length already or is `NULL`,
 #'   otherwise if it is scalar the replicated version of it with `n` entries.
@@ -99,12 +99,12 @@ to_n <- function(x, n) {
   }
 }
 
-#' Check Element Dimension
+#' Check element dimension
 #'
 #' Checks if the elements in `...` have the same dimension.
 #'
-#' @param ... (`data.frame`s or `vector`s)\cr any data frames/vectors.
-#' @param omit_null (`logical`)\cr whether `NULL` elements in `...` should be omitted from the check.
+#' @param ... (`data.frame` or `vector`)\cr any data frames or vectors.
+#' @param omit_null (`flag`)\cr whether `NULL` elements in `...` should be omitted from the check.
 #'
 #' @return A `logical` value.
 #'
@@ -135,13 +135,34 @@ check_same_n <- function(..., omit_null = TRUE) {
 
   if (length(unique(n)) > 1) {
     sel <- which(n != n[1])
-    stop("dimension mismatch:", paste(names(n)[sel], collapse = ", "), " do not have N=", n[1])
+    stop("Dimension mismatch:", paste(names(n)[sel], collapse = ", "), " do not have N=", n[1])
   }
 
   TRUE
 }
 
-#' Make Names Without Dots
+#' Utility function to check if a float value is equal to another float value
+#'
+#' Uses `.Machine$double.eps` as the tolerance for the comparison.
+#'
+#' @param x (`numeric(1)`)\cr a float number.
+#' @param y (`numeric(1)`)\cr a float number.
+#'
+#' @return `TRUE` if identical, otherwise `FALSE`.
+#'
+#' @keywords internal
+.is_equal_float <- function(x, y) {
+  checkmate::assert_number(x)
+  checkmate::assert_number(y)
+
+  # Define a tolerance
+  tolerance <- .Machine$double.eps
+
+  # Check if x is close enough to y
+  abs(x - y) < tolerance
+}
+
+#' Make names without dots
 #'
 #' @param nams (`character`)\cr vector of original names.
 #'
@@ -153,14 +174,14 @@ make_names <- function(nams) {
   gsub(".", "", x = orig, fixed = TRUE)
 }
 
-#' Conversion of Months to Days
+#' Conversion of months to days
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
-#' Conversion of Months to Days. This is an approximative calculation because it
+#' Conversion of months to days. This is an approximative calculation because it
 #' considers each month as having an average of 30.4375 days.
 #'
-#' @param x (`numeric`)\cr time in months.
+#' @param x (`numeric(1)`)\cr time in months.
 #'
 #' @return A `numeric` vector with the time in days.
 #'
@@ -174,9 +195,9 @@ month2day <- function(x) {
   x * 30.4375
 }
 
-#' Conversion of Days to Months
+#' Conversion of days to months
 #'
-#' @param x (`numeric`)\cr time in days.
+#' @param x (`numeric(1)`)\cr time in days.
 #'
 #' @return A `numeric` vector with the time in months.
 #'
@@ -208,7 +229,7 @@ empty_vector_if_na <- function(x) {
   }
 }
 
-#' Combine Two Vectors Element Wise
+#' Element-wise combination of two vectors
 #'
 #' @param x (`vector`)\cr first vector to combine.
 #' @param y (`vector`)\cr second vector to combine.
@@ -228,7 +249,7 @@ combine_vectors <- function(x, y) {
   result
 }
 
-#' Extract Elements by Name
+#' Extract elements by name
 #'
 #' This utility function extracts elements from a vector `x` by `names`.
 #' Differences to the standard `[` function are:
@@ -257,15 +278,15 @@ extract_by_name <- function(x, names) {
   }
 }
 
-#' Labels for Adverse Event Baskets
+#' Labels for adverse event baskets
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
-#' @param aesi (`character`)\cr with standardized `MedDRA` query name (e.g. `SMQzzNAM`) or customized query
-#'   name (e.g. `CQzzNAM`).
-#' @param scope (`character`)\cr with scope of query (e.g. `SMQzzSC`).
+#' @param aesi (`character`)\cr vector with standardized MedDRA query name (e.g. `SMQxxNAM`) or customized query
+#'   name (e.g. `CQxxNAM`).
+#' @param scope (`character`)\cr vector with scope of query (e.g. `SMQxxSC`).
 #'
-#' @return A `string` with the standard label for the `AE` basket.
+#' @return A `string` with the standard label for the AE basket.
 #'
 #' @examples
 #' adae <- tern_ex_adae
@@ -298,7 +319,7 @@ aesi_label <- function(aesi, scope = NULL) {
   lbl
 }
 
-#' Indicate Study Arm Variable in Formula
+#' Indicate study arm variable in formula
 #'
 #' We use `study_arm` to indicate the study arm variable in `tern` formulas.
 #'
@@ -311,17 +332,17 @@ study_arm <- function(x) {
   structure(x, varname = deparse(substitute(x)))
 }
 
-#' Smooth Function with Optional Grouping
+#' Smooth function with optional grouping
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
 #' This produces `loess` smoothed estimates of `y` with Student confidence intervals.
 #'
 #' @param df (`data.frame`)\cr data set containing all analysis variables.
-#' @param x (`character`)\cr value with x column name.
-#' @param y (`character`)\cr value with y column name.
-#' @param groups (`character`)\cr vector with optional grouping variables names.
-#' @param level (`numeric`)\cr level of confidence interval to use (0.95 by default).
+#' @param x (`string`)\cr x column name.
+#' @param y (`string`)\cr y column name.
+#' @param groups (`character` or `NULL`)\cr vector with optional grouping variables names.
+#' @param level (`proportion`)\cr level of confidence interval to use (0.95 by default).
 #'
 #' @return A `data.frame` with original `x`, smoothed `y`, `ylow`, and `yhigh`, and
 #'   optional `groups` variables formatted as `factor` type.
@@ -358,8 +379,8 @@ get_smooths <- function(df, x, y, groups = NULL, level = 0.95) {
         data.frame(
           x = d[[x]],
           y = plx$fit,
-          ylow = plx$fit - stats::qt(level, plx$df) * plx$se,
-          yhigh = plx$fit + stats::qt(level, plx$df) * plx$se
+          ylow = plx$fit - stats::qt(level, plx$df) * plx$se.fit,
+          yhigh = plx$fit + stats::qt(level, plx$df) * plx$se.fit
         )
       })
 
@@ -375,19 +396,19 @@ get_smooths <- function(df, x, y, groups = NULL, level = 0.95) {
     df_smooth <- data.frame(
       x = df_c[[x]],
       y = plx$fit,
-      ylow = plx$fit - stats::qt(level, plx$df) * plx$se,
-      yhigh = plx$fit + stats::qt(level, plx$df) * plx$se
+      ylow = plx$fit - stats::qt(level, plx$df) * plx$se.fit,
+      yhigh = plx$fit + stats::qt(level, plx$df) * plx$se.fit
     )
 
     df_smooth
   }
 }
 
-#' Number of Available (Non-Missing Entries) in a Vector
+#' Number of available (non-missing entries) in a vector
 #'
 #' Small utility function for better readability.
 #'
-#' @param x (`any`)\cr vector in which to count non-missing values.
+#' @param x (`vector`)\cr vector in which to count non-missing values.
 #'
 #' @return Number of non-missing values.
 #'
@@ -396,7 +417,7 @@ n_available <- function(x) {
   sum(!is.na(x))
 }
 
-#' Reapply Variable Labels
+#' Reapply variable labels
 #'
 #' This is a helper function that is used in tests.
 #'
