@@ -69,12 +69,16 @@ testthat::test_that("extract_rsp_subgroups works as expected with groups_lists",
 testthat::test_that("extract_rsp_subgroups functions as expected with strata", {
   adrs <- adrs_100
 
-  result <- extract_rsp_subgroups(
-    variables = list(rsp = "rsp", arm = "ARM", subgroups = c("SEX", "STRATA2"), strat = c("STRATA1")),
-    data = adrs,
-    conf_level = 0.9,
-    method = "cmh",
-    label_all = "ALL"
+  # https://github.com/therneau/survival/issues/240
+  withr::with_options(
+    opts_partial_match_old,
+    result <- extract_rsp_subgroups(
+      variables = list(rsp = "rsp", arm = "ARM", subgroups = c("SEX", "STRATA2"), strata = c("STRATA1")),
+      data = adrs,
+      conf_level = 0.9,
+      method = "cmh",
+      label_all = "ALL"
+    )
   )
 
   res <- testthat::expect_silent(result)
